<?php

namespace FiloBlu\ExtMagentoWidget\Model;

class Widget extends \Magento\Widget\Model\Widget
{
    private $mathRandom;
    
    /**
     * Return widget presentation code in WYSIWYG editor
     *
     * @param string $type Widget Type
     * @param array $params Pre-configured Widget Params
     * @param bool $asIs Return result as widget directive(true) or as placeholder image(false)
     * @return string Widget directive ready to parse
     * @api
     */
    public function getWidgetDeclaration($type, $params = [], $asIs = true, $customer_group = null)
    {
        $customer_group_str = "";
        if ($customer_group) {
            $customer_group_str = ' widget_display_customer_group="' . implode(",",$customer_group) . '" ';
        }
        $widget = $this->getConfigAsObject($type);
        $directive = '{{widget type="' . $type . '"' . $customer_group_str;

        foreach ($params as $name => $value) {
            // Retrieve default option value if pre-configured
            if ($name == 'conditions') {
                $name = 'conditions_encoded';
                $value = $this->conditionsHelper->encode($value);
            } elseif (is_array($value)) {
                $value = implode(',', $value);
            } elseif (trim($value) == '') {                
                $parameters = $widget->getParameters();
                if (isset($parameters[$name]) && is_object($parameters[$name])) {
                    $value = $parameters[$name]->getValue();
                }
            }
            if (isset($value)) {
                $directive .= sprintf(' %s="%s"', $name, $this->escaper->escapeQuote($value));
            }
        }
        $directive .= sprintf(' type_name="%s"', $widget['name']);
        $directive .= $this->getWidgetPageVarName($params);
        $directive .= '}}';

        if ($asIs) {
            return $directive;
        }

        $html = sprintf(
            '<img id="%s" src="%s" title="%s">',
            $this->idEncode($directive),
            $this->getPlaceholderImageUrl($type),
            $this->escaper->escapeUrl($directive)
        );
        return $html;
    }
    
    
    /**
     * @param array $params
     * @return string
     * @throws \Magento\Framework\Exception\LocalizedException
     */
    private function getWidgetPageVarName($params = [])
    {
        $pageVarName = '';
        if (array_key_exists('show_pager', $params) && (bool)$params['show_pager']) {
            $pageVarName = sprintf(
                ' %s="%s"',
                'page_var_name',
                'p' . $this->getMathRandom()->getRandomString(5, \Magento\Framework\Math\Random::CHARS_LOWERS)
            );
        }
        return $pageVarName;
    }
    
     /**
     * @return \Magento\Framework\Math\Random
     *
     * @deprecated
     */
    private function getMathRandom()
    {
        if ($this->mathRandom === null) {
            $this->mathRandom = \Magento\Framework\App\ObjectManager::getInstance()
                ->get(\Magento\Framework\Math\Random::class);
        }
        return $this->mathRandom;
    }
}
